@@ -1,2 +1,2 @@
 from simple_websocket.ws import Server, Client, ConnectionError, \
-    ConnectionClosed
+    ConnectionClosed  # noqa: F401
